# generateOutlookABook.py: generate a CSV file to import into Outlook
# 2003 address book.
# Bob DuCharme no warrantee expressed or implied. 

import sys
from addressBookLib import *

# following names from an Outlook export. When file starts with this, Outlook doesn't make me map fields, but we don't want it when importing to MySQL.

#print '"Title","First Name","Middle Name","Last Name","Suffix","Company","Department","Job Title","Business Street","Business Street 2","Business Street 3","Business City","Business State","Business Postal Code","Business Country","Home Street","Home Street 2","Home Street 3","Home City","Home State","Home Postal Code","Home Country","Other Street","Other Street 2","Other Street 3","Other City","Other State","Other Postal Code","Other Country","Assistant\'s Phone","Business Fax","Business Phone","Business Phone 2","Callback","Car Phone","Company Main Phone","Home Fax","Home Phone","Home Phone 2","ISDN","Mobile Phone","Other Fax","Other Phone","Pager","Primary Phone","Radio Phone","TTY/TDD Phone","Telex","Account","Anniversary","Assistant\'s Name","Billing Information","Birthday","Business Address PO Box","Categories","Children","Directory Server","E-mail Address","E-mail Type","E-mail Display Name","E-mail 2 Address","E-mail 2 Type","E-mail 2 Display Name","E-mail 3 Address","E-mail 3 Type","E-mail 3 Display Name","Gender","Government ID Number","Hobby","Home Address PO Box","Initials","Internet Free Busy","Keywords","Language","Location","Manager\'s Name","Mileage","Notes","Office Location","Organizational ID Number","Other Address PO Box","Priority","Private","Profession","Referred By","Sensitivity","Spouse","User 1","User 2","User 3","User 4","Web Page"'

def generateRecord():
  # Save the following because they're used to create some of the other values.
  fn = firstName()
  ln = lastName()
  comp = company()
  compDomainName = companyDomainName(comp)

  note = ""
  if randint(0,2) < 1:
    note = "Here is a sample note.\\n\\nThat was two carriage returns."

  rec = ''
  
  # "Title","First Name","Middle Name","Last Name",
  rec = rec + q(jobTitle()) + q(fn) + q(middleName()) + q(ln)
  # "Suffix","Company","Department","Job Title",
  rec = rec + q(nameSuffix()) + q(comp) + q("") + q("director")
  #"Business Street","Business Street 2","Business Street 3","Business City",
  rec = rec + q(someInt() + " " + streetName()) + q(optionalAddrLine()) + '"",' + q(city())
  # "Business State","Business Postal Code","Business Country","Home Street",
  rec = rec + q(stateCode()) + q(zipCode()) + '"US",' +  q(someInt() + " " + streetName())
  # "Home Street 2","Home Street 3","Home City","Home State",
  rec = rec +  q(optionalAddrLine()) + '"",' + q(city()) + q(stateCode())
  # "Home Postal Code","Home Country","Other Street","Other Street 2",
  rec = rec + q(zipCode()) + '"US","","",'
  # "Other Street 3","Other City","Other State","Other Postal Code",
  rec = rec + '"","","","",'
  # "Other Country","Assistant's Phone","Business Fax","Business Phone",
  rec = rec + '"","",' + q(phoneNumber()) +  q(phoneNumber())
  # "Business Phone 2","Callback","Car Phone","Company Main Phone",
  rec = rec + '"","","",' + q(phoneNumber())
  # "Home Fax","Home Phone","Home Phone 2","ISDN",
  rec = rec +  q(phoneNumber()) + q(phoneNumber()) + '"","",'
  # "Mobile Phone","Other Fax","Other Phone","Pager",
  rec = rec +  q(phoneNumber()) + '"","","",'
  # "Primary Phone","Radio Phone","TTY/TDD Phone","Telex",
  rec = rec +  q(phoneNumber()) + '"","","",'
  # "Account","Anniversary","Assistant's Name","Billing Information",
  rec = rec + '"","","","",'
  # "Birthday","Business Address PO Box","Categories","Children",
  rec = rec + q(birthday()) + '"",' + q(categories()) + q(children())
  # "Directory Server","E-mail Address","E-mail Type","E-mail Display Name",
  rec = rec + '"",' + q(companyEmailAddr(fn,ln,compDomainName)) + '"work",' + q(fn)
  # "E-mail 2 Address","E-mail 2 Type","E-mail 2 Display Name","E-mail 3 Address",
  rec = rec + q(homeEmailAddr(fn)) + '"home",' + q(fn) + '"",'
  # "E-mail 3 Type","E-mail 3 Display Name","Gender","Government ID Number",
  rec = rec + '"","","","",'
  # "Hobby","Home Address PO Box","Initials","Internet Free Busy",
  rec = rec + '"","","","",'
  # "Keywords","Language","Location","Manager's Name",
  rec = rec + '"","","","",'
  # "Mileage","Notes","Office Location","Organizational ID Number",
  rec = rec + '"",' + q(note) + '"","",'
  # "Other Address PO Box","Priority","Private","Profession",
  rec = rec + '"","","","",'
  # "Referred By","Sensitivity","Spouse","User 1",
  rec = rec + '"","","","",'
  # "User 2","User 3","User 4","Web Page","Notes
  rec = rec + '"","","","http://www.' +  compDomainName + '/' + fn + '"'

  return rec



# --- Main program


if __name__ == "__main__":

    if len(sys.argv) != 2:
        print "Enter\n\n  python generateOutlookAbook.py  N\n"
        print "where N is the number of CSV records to output."
        sys.exit()

    recs2Create = int(sys.argv[1]) + 1;

# If data will be imported into Outlook, we do want following line so
# that we can skip field mapping. If importing into MySQL, we don't
# want it.

#print '"title","firstName","middleName","lastName","suffi","company","department","jobTitle","businessStreet","businessStreet2","businessStreet3","businessCity","bs","bPCode","businessCountry","homeStreet","homeStreet2","homeStreet3","homeCity","hs","hPCode","homeCountry","otherStreet","otherStreet2","otherStreet3","otherCity","oS","oPCode","otherCountry","assistantsPhone","businessFax","businessPhone","businessPhone2","callback","carPhone","companyMainPhone","homeFax","homePhone","homePhone2","ISDN","mobilePhone","otherFax","otherPhone","pager","primaryPhone","radioPhone","TTYTDDPhone","telex","account","anniversary","assistantsName","billingInformation","birthday","baPOBox","categories","children","directoryServer","emailAddress","emailType","emailDisplayName","email2Address","email2Type","email2DisplayName","email3Address","email3Type","email3DisplayName","g","governmentIDNumber","hobby","hAPOBox","ini","internetFreeBusy","keywords","lang","location","managersName","mile","notes","officeLocation","oIDNumber","oAPOBox","pri","p","profession","referredBy","sensitivity","spouse","user1","user2","user3","user4","webPage"'

    for r in range(1,recs2Create):
      print generateRecord(),
      #MySQL doesn't like a carriage return at the end of the last line. 
      if r < recs2Create - 1:
        print;

